@@ -1,4 +1,5 @@
-from .spreadsheet import Spreadsheet  # noqa
+from .work_book import WorkBook, ExcelParameters, DictionaryParameters, ListParameters  # noqa
+from .sheet import Sheet  # noqa
 from .cell import Cell  # noqa
 from .cell_indices import CellIndices  # noqa
 from .cell_slice import CellSlice  # noqa
@@ -6,5 +7,5 @@ from .grammars import GRAMMARS  # noqa
 from .grammar_utils import GrammarUtils  # noqa
 from .skipped_label import SkippedLabel  # noqa
 
-__version__ = "1.0.0"
+__version__ = "2.1.5"
 __status__ = "Production"
