@@ -1,4 +1,5 @@
-from typing import Dict, Optional, Iterable, Tuple, Callable, Union
+from typing import Dict, Optional, Iterable, Tuple, \
+    Callable, Union, TYPE_CHECKING
 
 import numpy as np
 import numpy_financial as npf
@@ -6,6 +7,8 @@ import numpy_financial as npf
 from .word_constructor import WordConstructor
 from .cell_type import CellType
 from .cell_indices import CellIndices
+if TYPE_CHECKING:
+    from .sheet import Sheet
 
 
 class CellValueError(ValueError):
@@ -32,10 +35,17 @@ class Cell(object):
         _excel_format (dict): Dictionary defining the Excel format style
             for the cell.
         _description (Optional[str]): Optional description of the cell.
+        _excel_row_position (Optional[int]): Position of the variable in
+            variable sheet in Excel.
+        _variable_words (WordConstructor): The word defining computational
+            operations of (computational) variable. Computational variable is
+            variable defined by formulas.
+        excel_data_validation (dict): Define data validation restriction
+            based on xlsxwriter 'data_validation' possibilities.
     """
     def __init__(self,
                  row: Optional[int] = None,
-                 column: Optional[int] = None, /,  # noqa E999
+                 column: Optional[int] = None, /,  # noqa: E225
                  value: Optional[float] = None, *,
                  cell_indices: CellIndices,
                  # Private arguments
@@ -73,6 +83,7 @@ class Cell(object):
         self.variable_name: Optional[str] = variable_name
         self._excel_format: dict = {}
         self._description: Optional[str] = None
+        self._excel_row_position: Optional[int] = None
 
         if words is not None:
             self._constructing_words: WordConstructor = words
@@ -80,6 +91,9 @@ class Cell(object):
             self._constructing_words: WordConstructor = \
                 WordConstructor.init_from_new_cell(self)
 
+        self._variable_words: WordConstructor = None
+        self.excel_data_validation: dict = None
+
     # === CLASS METHODS and PROPERTIES: ===
     @property
     def word(self) -> WordConstructor:
@@ -165,6 +179,18 @@ class Cell(object):
         """
         return self._constructing_words.parse(self)
 
+    @property
+    def parse_variable(self) -> Dict[str, str]:
+        """Return the dictionary with keys: language, values: constructing
+            word. This function is called when the cell should be inserted to
+            a variable spreadsheet. This differs from 'parse' as variables
+            might be computational.
+
+        Returns:
+            Dict[str, str]: Words for each language
+        """
+        return self._constructing_words.parse(self, True)
+
     @property
     def excel_format(self) -> dict:
         """Return style/format of the cell for Excel.
@@ -187,6 +213,43 @@ class Cell(object):
             raise ValueError("New format has to be a dictionary!")
         self._excel_format = new_format
 
+    @property
+    def excel_row_position(self):
+        """Get the row position of the variable in Excel variable sheet.
+
+        Returns:
+            Optional[int]: row index of the variable.
+        """
+        if self.is_variable:
+            return self._excel_row_position
+        raise CellValueError("This operation is supported only for variables.")
+
+    @excel_row_position.setter
+    def excel_row_position(self, value: Optional[int]):
+        """Set the row position of the variable.
+
+        Args:
+            value (Optional[int]): row index of the variable. If None, the
+                default place is used.
+        """
+        if self.is_variable:
+            self._excel_row_position = value
+        else:
+            raise CellValueError(
+                "This operation is supported only for variables."
+            )
+
+    @property
+    def computational_variable(self):
+        """Return True, if the variable is computational (contains some
+            formulas). False, if it is only a value.
+
+        Returns:
+            bool: True, if the variable is computational (contains some
+                formulas). False, if it is only value.
+        """
+        return self._variable_words is not None
+
     @property
     def description(self) -> Optional[str]:
         """Return description of the cell or None.
@@ -223,7 +286,8 @@ class Cell(object):
         """
         try:
             return function(**operands)
-        except BaseException:  # noqa Maximally generic here is OK
+        except BaseException:  # noqa
+            # Maximally generic here is OK
             return CellValueError()
 
     # =====================================
@@ -744,7 +808,7 @@ class Cell(object):
 
     # === UNARY OPERATORS: ===
     @staticmethod
-    def reference(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def reference(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """Create a reference to some anchored cell.
 
         Args:
@@ -762,6 +826,27 @@ class Cell(object):
                     cell_type=CellType.computational
                     )
 
+    @staticmethod
+    def cross_reference(target: 'Cell', sheet: 'Sheet') -> 'Cell':
+        """Cross reference to other sheet in the workbook.
+
+        Args:
+            target (Cell): Target cell in a different sheet.
+            sheet (Sheet): Sheet of the target cell.
+
+        Return:
+            Cell: reference to the different location.
+        """
+
+        if not target.anchored:
+            raise ValueError("The referenced cell has to be anchored.")
+
+        return Cell(value=Cell._compute_value(lambda x: x.value, x=target),
+                    words=WordConstructor.cross_reference(target, sheet),
+                    cell_indices=target.cell_indices,
+                    cell_type=CellType.computational
+                    )
+
     @staticmethod
     def raw(other: 'Cell', words: Dict[str, str], /) -> 'Cell':  # noqa: E225
         """Add the raw statement and use the value of input cell.
@@ -781,7 +866,7 @@ class Cell(object):
                     )
 
     @staticmethod
-    def variable(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def variable(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """The cell as a variable.
 
         Args:
@@ -799,7 +884,7 @@ class Cell(object):
                     )
 
     @staticmethod
-    def brackets(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def brackets(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """Add brackets to expression.
 
         Args:
@@ -815,7 +900,7 @@ class Cell(object):
                     )
 
     @staticmethod
-    def logarithm(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def logarithm(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """Logarithm of the value in the cell.
 
         Args:
@@ -832,7 +917,7 @@ class Cell(object):
                     )
 
     @staticmethod
-    def exponential(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def exponential(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """Exponential of the value in the cell.
 
         Args:
@@ -849,7 +934,7 @@ class Cell(object):
                     )
 
     @staticmethod
-    def ceil(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def ceil(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """Ceiling function of the value in the cell.
 
         Args:
@@ -866,7 +951,7 @@ class Cell(object):
                     )
 
     @staticmethod
-    def floor(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def floor(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """Floor function of the value in the cell.
 
         Args:
@@ -883,7 +968,7 @@ class Cell(object):
                     )
 
     @staticmethod
-    def round(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def round(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """Round the value in the cell.
 
         Args:
@@ -900,7 +985,7 @@ class Cell(object):
                     )
 
     @staticmethod
-    def abs(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def abs(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """Absolute value of the value in the cell.
 
         Args:
@@ -917,7 +1002,7 @@ class Cell(object):
                     )
 
     @staticmethod
-    def sqrt(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def sqrt(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """Square root of the value in the cell.
 
         Args:
@@ -934,7 +1019,7 @@ class Cell(object):
                     )
 
     @staticmethod
-    def signum(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def signum(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """Signum function of the value in the cell.
 
         Args:
@@ -951,7 +1036,7 @@ class Cell(object):
                     )
 
     @staticmethod
-    def logicalNegation(other: 'Cell', /) -> 'Cell':  # noqa E225
+    def logicalNegation(other: 'Cell', /) -> 'Cell':  # noqa: E225
         """Logical negation of the value in the cell.
 
         Args:
@@ -972,7 +1057,7 @@ class Cell(object):
     @staticmethod
     def conditional(condition: 'Cell',
                     consequent: 'Cell',
-                    alternative: 'Cell', /) -> 'Cell':  # noqa E225
+                    alternative: 'Cell', /) -> 'Cell':  # noqa: E225
         """Conditional statement (standard if-then-else statement).
 
         Evaluate the value of the condition, if it is true, take the value
@@ -1004,7 +1089,7 @@ class Cell(object):
     @staticmethod
     def offset(reference: 'Cell',
                row_skip: 'Cell',
-               column_skip: 'Cell', /, *, # noqa E225
+               column_skip: 'Cell', /, *,  # noqa: E225
                target: 'Cell') -> 'Cell':
         """Return the cell with value computed as offset from reference cell
             plus row_skip rows and column_skip columns.
@@ -1035,3 +1120,43 @@ class Cell(object):
                     cell_type=CellType.computational
                     )
     # ==============
+
+    # === LINEAR REGRESSION ===
+    @staticmethod
+    def linear_interpolation(
+        x_start: 'Cell',
+        y_start: 'Cell',
+        x_end: 'Cell',
+        y_end: 'Cell',
+        x: 'Cell'
+    ) -> 'Cell':
+        """Return the cell defining linear interpolation at some point.
+
+        Args:
+            x_start (Cell): Where is the x coordinate of the start.
+            y_start (Cell): Where is the y OR f(x) coordinate of the start.
+            x_end (Cell): Where is the x coordinate of the end.
+            y_end (Cell): Where is the y OR f(x) coordinate of the end.
+            x (Cell): For what value of x are we interpolating.
+
+        Returns:
+            Cell: Linear interpolation of values.
+        """
+        return Cell(value=Cell._compute_value(
+                        lambda x_s, y_s, x_e, y_e, x_v:
+                        # y = Ax + B
+                        # A:
+                        (y_e.value - y_s.value) / (x_e.value - x_s.value) *
+                        x.value +
+                        # B:
+                        y_e.value - x_e.value *  # A again:
+                        (y_e.value - y_s.value) / (x_e.value - x_s.value),
+                        x_s=x_start, y_s=y_start, x_e=x_end, y_e=y_end, x_v=x
+                    ),
+                    words=WordConstructor.linear_interpolation(
+                        x_start, y_start, x_end, y_end, x
+                    ),
+                    cell_indices=x.cell_indices,
+                    cell_type=CellType.computational
+                    )
+    # =========================
