@@ -38,6 +38,16 @@ EXCEL = {
             "separator": "",
             "row_first": False
         },
+        # Like 'Sheet 3'!D8 (MS Excel format, LibreOffice Calc can parse it)
+        "cross-reference": {
+            "cell-prefix": "",
+            "cell-suffix": "",
+            "cell-separator": "",
+            "sheet-prefix": "'",
+            "sheet-suffix": "'!",
+            "row-first": False,
+            "sheet-first": True
+        },
         # like =7+A2
         "operation": {
             "prefix": "=",
@@ -284,6 +294,9 @@ EXCEL = {
             "prefix": "",
             "suffix": ""
         }
+    },
+    "linear-interpolation": {
+        "word": "({x}-{x_e})*(({y_e}-{y_s})/({x_e}-{x_s}))+{y_e}"
     }
 }
 NATIVE = {
@@ -326,6 +339,16 @@ NATIVE = {
             "separator": ", ",
             "row_first": True
         },
+        # Like value at (row, col) in sheet 'xyz'
+        "cross-reference": {
+            "cell-prefix": "value at (",
+            "cell-suffix": ")",
+            "cell-separator": ", ",
+            "sheet-prefix": " in the sheet '",
+            "sheet-suffix": "'",
+            "row-first": True,
+            "sheet-first": False
+        },
         # like 7 + value at (1.1.2015, 25%)
         "operation": {
             "prefix": "",
@@ -573,6 +596,10 @@ NATIVE = {
             "prefix": " else ",
             "suffix": ""
         }
+    },
+    "linear-interpolation": {
+        "word": "linear interpolation at point {x} for "
+                "x values ({x_s}, {x_e}) and f(x) values ({y_s}, {y_e})"
     }
 }
 PYTHON_NUMPY = {
@@ -615,6 +642,16 @@ PYTHON_NUMPY = {
             "separator": ",",
             "row_first": True
         },
+        # Like sheet.values[row,column]
+        "cross-reference": {
+            "cell-prefix": "values[",
+            "cell-suffix": "]",
+            "cell-separator": ",",
+            "sheet-prefix": "",
+            "sheet-suffix": ".",
+            "row-first": True,
+            "sheet-first": True
+        },
         # like 7+values[1,2] (in Python case do nothing)
         "operation": {
             "prefix": "",
@@ -861,6 +898,9 @@ PYTHON_NUMPY = {
             "prefix": "else (",
             "suffix": ")"
         }
+    },
+    "linear-interpolation": {
+        "word": "np.interp({x}, [{x_s}, {x_e}], [{y_s}, {y_e}])"
     }
 }
 
@@ -936,6 +976,21 @@ GRAMMAR_PATTERN: dict = {
             "row_first": bool
         },
 
+        # Cross reference to a cell (like =$'Sheet 3'.D8 in Excel)
+        "cross-reference": {
+            "cell-prefix": str,
+            "cell-suffix": str,
+            "cell-separator": str,
+            # Prefix and suffix defining the sheet
+            "sheet-prefix": str,
+            "sheet-suffix": str,
+            # If True, the row is on the first position and column on the
+            # second position. (e. g. it is False for Excel)
+            "row-first": bool,
+            # If True, the name of sheet is the first parameter
+            "sheet-first": bool
+        },
+
         # Operation (like =CELL + CELL)
         "operation": {
             "prefix": str,
@@ -1242,5 +1297,17 @@ GRAMMAR_PATTERN: dict = {
             "prefix": str,
             "suffix": str
         }
+    },
+
+    # Linear interpolation
+    "linear-interpolation": {
+        # This require a special format
+        # Word represents the whole word, reserved values in the string are:
+        #   {x_s}: for x value of starting point
+        #   {y_s}: for y value of starting point
+        #   {x_e}: for x value of ending point
+        #   {y_e}: for y value of ending point
+        #   {x}: value where the interpolation is evaluated
+        "word": str
     }
 }
