@@ -3,6 +3,7 @@ import json
 from typing import Tuple, List, Dict, Union, Callable, Optional
 from types import MappingProxyType
 from numbers import Number
+import pathlib
 
 import xlsxwriter
 import numpy
@@ -11,6 +12,9 @@ from .cell import Cell, CellValueError
 from .cell_type import CellType
 from .cell_indices import CellIndices
 from .skipped_label import SkippedLabel
+from .serialization_interface import SerializationInterface
+from .utils import NumPyEncoder
+from .cell_indices_templates import excel_column
 
 # ==== TYPES ====
 # Type for the output dictionary with the logic:
@@ -68,7 +72,7 @@ T_out_dict = Dict[
 # ===============
 
 
-class Serialization(abc.ABC):
+class Serialization(SerializationInterface, abc.ABC):
     """Provides basic functionality for exporting to required formats.
 
     Attributes:
@@ -78,21 +82,24 @@ class Serialization(abc.ABC):
         warning_logger (Callable[[str], None]): Function that logs the
             warnings.
         export_subset (bool): If true, warning are raised when exporting.
+        name (Optional[str]): Name of this object (typically sheet).
     """
 
     def __init__(self, *,
                  export_offset: Tuple[int, int] = (0, 0),
                  export_subset: bool = False,
-                 warning_logger: Optional[Callable[[str], None]] = None):
+                 warning_logger: Optional[Callable[[str], None]] = None,
+                 name: Optional[str] = "Results"):
         """Initialise functionality for serialization.
 
         Args:
             export_offset (Tuple[int, int]): Defines how many rows and
-                columns are skiped from the left top corner. First index is
+                columns are skipped from the left top corner. First index is
                 number of rows, second number of columns.
             export_subset (bool): If true, warning are raised when exporting.
             warning_logger (Optional[Callable[[str], None]]): Function that
                 logs the warnings (or None if skipped).
+            name (Optional[str]): Name of this object (typically sheet).
         """
         # Export offset of rows, columns
         self.export_offset: Tuple[int, int] = export_offset
@@ -102,6 +109,7 @@ class Serialization(abc.ABC):
             # Silent logger
             self.warning_logger: Callable[[str], None] = lambda _mess: _mess
         self.export_subset: bool = export_subset
+        self.name: Optional[str] = name
 
     @property
     def shape(self) -> Tuple[int, int]:
@@ -146,29 +154,133 @@ class Serialization(abc.ABC):
             self.warning_logger("Slice is being exported => there is"
                                 " a possibility of data losses.")
 
-    def to_excel(self,
-                 file_path: str,
-                 /, *,  # noqa: E225, E999
-                 sheet_name: str = "Results",
-                 spaces_replacement: str = ' ',
-                 label_row_format: dict = {'bold': True},
-                 label_column_format: dict = {'bold': True},
-                 variables_sheet_name: Optional[str] = None,
-                 variables_sheet_header: Dict[str, str] = MappingProxyType(
-                     {
-                         "name": "Name",
-                         "value": "Value",
-                         "description": "Description"
-                     }),
-                 values_only: bool = False,
-                 skipped_label_replacement: str = ''
-                 ) -> None:
-        """Export the values inside Spreadsheet instance to the
+    def _excel_register_variables(self, workbook):
+        """Register variables in Excel spreadsheet.
+
+        Args:
+            workbook: Workbook where variables are registered.
+        """
+        # Just register variables (without writing them to sheet)
+        for name, value in self._get_variables().get_variables_dict(
+            False
+        ).items():
+            workbook.define_name(name, str(value['value']))
+
+    @staticmethod
+    def _excel_write_variables_to_sheet(workbook: object,
+                                        variables_sheet: object,
+                                        variables: List[object],
+                                        offset_rows: int = 0,
+                                        offset_columns: int = 0,
+                                        col_label_format: object = None,
+                                        header: Optional[Dict[str, str]] = None
+                                        ) -> object:
+        """Create sheet with variables.
+
+        Args:
+            workbook (object): Workbook where variables are registered.
+            variables_sheet (object): Sheet where variables are defined.
+            variables (List[object]): List of variables set.
+            offset_rows (int): How many rows should be skipped.
+            offset_columns (int): How many columns should be skipped.
+            header (Optional[Dict[str, str]]): Definition of the first line
+                with header. If None, header line is skipped.
+            col_label_format (object): Define style for header.
+
+        Returns:
+            xlsxwriter.worksheet.Worksheet: Worksheet with variables
+        """
+        row_idx = offset_rows
+        if header:
+            # Insert header (labels)
+            variables_sheet.write(row_idx, offset_columns + 0,
+                                  header['name'], col_label_format)
+            variables_sheet.write(row_idx, offset_columns + 1,
+                                  header['value'], col_label_format)
+            variables_sheet.write(row_idx, offset_columns + 2,
+                                  header['description'], col_label_format)
+            row_idx += 1
+
+        for var_set in variables:
+            for var_n, var_v in var_set.get_variables_dict(True).items():
+                variable_row_position = var_v['cell'].excel_row_position
+                if variable_row_position is None:
+                    variable_row_position = row_idx
+                    row_idx += 1
+
+                # Format the variable style
+                try:
+                    style_var = var_v['cell'].excel_format
+                    variable_style = workbook.add_format(style_var)
+                except KeyError:
+                    variable_style = None
+                # Insert variables to the sheet
+                variables_sheet.write(variable_row_position,
+                                      offset_columns + 0,
+                                      var_n)
+                if not var_v['cell'].computational_variable:
+                    # In the case that variable contains only the value
+                    variables_sheet.write(
+                        variable_row_position,
+                        offset_columns + 1,
+                        var_v['value'],
+                        variable_style
+                    )
+                else:
+                    # For the case that variable contains computational formula
+                    variables_sheet.write_formula(
+                        variable_row_position,
+                        offset_columns + 1,
+                        var_v['cell'].parse_variable['excel'],
+                        value=var_v['value'],
+                        cell_format=variable_style
+                    )
+                if var_v['cell'].excel_data_validation is not None:
+                    variables_sheet.data_validation(
+                        variable_row_position,
+                        offset_columns + 1,
+                        variable_row_position,
+                        offset_columns + 1,
+                        var_v['cell'].excel_data_validation
+                    )
+
+                variables_sheet.write(variable_row_position,
+                                      offset_columns + 2,
+                                      var_v['description'])
+                # Register variable
+                workbook.define_name(
+                    var_n, '={}!${}${}'.format(
+                        variables_sheet.name,
+                        excel_column(offset_columns + 1),
+                        variable_row_position + 1  # now index from 1
+                    )
+                )
+        return variables_sheet
+
+    def _to_excel(self, *,
+                  spaces_replacement: str = ' ',
+                  label_row_format: dict = MappingProxyType({'bold': True}),
+                  label_column_format: dict = MappingProxyType({'bold': True}),
+                  variables_sheet_name: Optional[str] = None,
+                  variables_sheet_header: Dict[str, str] = MappingProxyType(
+                      {
+                          "name": "Name",
+                          "value": "Value",
+                          "description": "Description"
+                      }),
+                  values_only: bool = False,
+                  skipped_label_replacement: str = '',
+                  row_height: List[float] = tuple(),
+                  column_width: List[float] = tuple(),
+                  top_left_corner_text: str = "",
+                  workbook: xlsxwriter.Workbook,
+                  worksheet: Optional[object] = None,
+                  register_variables: bool = True
+                  ) -> object:
+        """Export the values inside Sheet instance to the
             Excel 2010 compatible .xslx file
 
         Args:
-            file_path (str): Path to the target .xlsx file.
-            sheet_name (str): The name of the sheet inside the file.
             spaces_replacement (str): All the spaces in the rows and columns
                 descriptions (labels) are replaced with this string.
             label_row_format (dict): Excel styles for the label of rows,
@@ -177,66 +289,61 @@ class Serialization(abc.ABC):
                 documentation: https://xlsxwriter.readthedocs.io/format.html
             variables_sheet_name (Optional[str]): If set, creates the new
                 sheet with variables and their description and possibility
-                to set them up (directly from the sheet).
+                to set them up (directly from the sheet). If None, does not
+                write any sheet (also when there is no variable).
             variables_sheet_header (Dict[str, str]): Define the labels (header)
                 for the sheet with variables (first row in the sheet).
             values_only (bool): If true, only values (and not formulas) are
                 exported.
             skipped_label_replacement (str): Replacement for the SkippedLabel
                 instances.
+            row_height (List[float]): List of row heights, or empty for the
+                default height (or None for default height in the series).
+                If row labels are included, there is a label row height on the
+                first position in array.
+            column_width (List[float]): List of column widths, or empty for the
+                default widths (or None for the default width in the series).
+                If column labels are included, there is a label column width
+                on the first position in array.
+            top_left_corner_text (str): Text in the top left corner. Apply
+                only when the row and column labels are included.
+            workbook (xlsxwriter.Workbook): Handler of the file.
+            worksheet (object): Sheet where values should be written.
+            register_variables (bool): If false, variable registration is
+                skipped.
+
+        Return:
+            object: Created worksheet.
         """
-        # Quick sanity check
-        if ".xlsx" not in file_path[-5:]:
-            raise ValueError("Suffix of the file has to be '.xslx'!")
-        if not isinstance(sheet_name, str) or len(sheet_name) < 1:
-            raise ValueError("Sheet name has to be non-empty string!")
         # Log warning if needed
         self.log_export_subset_warning_if_needed()
 
-        # Open or create an Excel file and create a sheet inside:
-        workbook = xlsxwriter.Workbook(file_path)
-        worksheet = workbook.add_worksheet(name=sheet_name)
-        # Register the style for the labels:
+        # A) Create a sheet inside Excel file:
+        if worksheet is None:
+            worksheet = workbook.add_worksheet(name=self.name)
+
+        # B) Register the style for the labels:
         col_label_format = workbook.add_format(label_column_format)
         row_label_format = workbook.add_format(label_row_format)
 
-        # Register all variables:
-        if self._get_variables().empty:
+        # C) Register all variables:
+        if self._get_variables().empty or not register_variables:
+            # If there are no variables, skip this
             pass
         elif variables_sheet_name is None:
-            for name, value in self._get_variables().variables_dict.items():
-                workbook.define_name(name, str(value['value']))
+            # Just register variables (without writing them to sheet)
+            self._excel_register_variables(workbook)
         else:
-            # Add variable
+            # Register variables and create the variable's sheet
             variables_sheet = workbook.add_worksheet(name=variables_sheet_name)
-            # Insert header (labels)
-            variables_sheet.write(0, 0, variables_sheet_header['name'],
-                                  col_label_format)
-            variables_sheet.write(0, 1, variables_sheet_header['value'],
-                                  col_label_format)
-            variables_sheet.write(0, 2, variables_sheet_header['description'],
-                                  col_label_format)
-            row_idx = 1
-            for var_n, var_v in self._get_variables().variables_dict.items():
-                # Format the variable style
-                try:
-                    style_var = self._get_variables().excel_format[var_n]
-                    variable_style = workbook.add_format(style_var)
-                except KeyError:
-                    variable_style = None
-                # Insert variables to the sheet
-                variables_sheet.write(row_idx, 0, var_n)
-                variables_sheet.write(
-                    row_idx, 1, var_v['value'], variable_style
-                )
-                variables_sheet.write(row_idx, 2, var_v['description'])
-                # Register variable
-                workbook.define_name(
-                    var_n, f'={variables_sheet_name}!$B${row_idx + 1}'
-                )
-                row_idx += 1
 
-        # Iterate through all columns and rows and add data
+            # Write variable sheet
+            self._excel_write_variables_to_sheet(
+                workbook, variables_sheet, [self._get_variables()], 0, 0,
+                col_label_format, variables_sheet_header
+            )
+
+        # D) Iterate through all columns and rows and add data
         for row_idx in range(self.shape[0]):
             for col_idx in range(self.shape[1]):
                 cell: Cell = self._get_cell_at(row_idx, col_idx)
@@ -276,7 +383,17 @@ class Serialization(abc.ABC):
                                                 cell.parse['excel'],
                                                 value=cell.value,
                                                 cell_format=cell_format)
-        # Add the labels for rows and columns
+                    # Add excel data validation (from xlsxwriter)
+                    if cell.excel_data_validation is not None:
+                        variables_sheet.data_validation(
+                            row_idx + offset_row,
+                            col_idx + offset_col,
+                            row_idx + offset_row,
+                            col_idx + offset_col,
+                            cell.excel_data_validation
+                        )
+
+        # E) Add the labels for rows and columns
         if self.cell_indices.excel_append_column_labels:
             # Add labels of column
             for col_idx in range(self.shape[1]):
@@ -307,20 +424,112 @@ class Serialization(abc.ABC):
                                 0,
                                 row_lbl,
                                 row_label_format)
-        # Store results
+            if self.cell_indices.excel_append_column_labels:
+                # Write the left/top corner text
+                worksheet.write(0, 0,
+                                top_left_corner_text,
+                                row_label_format)
+
+        # Set the row heights:
+        for row_position, s_row_height in enumerate(row_height):
+            if s_row_height is not None:
+                worksheet.set_row(row_position, s_row_height)
+
+        # Set the column widths:
+        for col_position, s_col_width in enumerate(column_width):
+            if s_col_width is not None:
+                worksheet.set_column(col_position, col_position, s_col_width)
+
+        # Return results
+        return worksheet, worksheet
+
+    def to_excel(self,
+                 file_path: Union[str, pathlib.Path],
+                 *,
+                 spaces_replacement: str = ' ',
+                 label_row_format: dict = {'bold': True},
+                 label_column_format: dict = {'bold': True},
+                 variables_sheet_name: Optional[str] = None,
+                 variables_sheet_header: Dict[str, str] = MappingProxyType(
+                     {
+                         "name": "Name",
+                         "value": "Value",
+                         "description": "Description"
+                     }),
+                 values_only: bool = False,
+                 skipped_label_replacement: str = '',
+                 row_height: List[float] = [],
+                 column_width: List[float] = [],
+                 top_left_corner_text: str = ""
+                 ) -> None:
+        """Export the values inside Sheet instance to the
+            Excel 2010 compatible .xslx file
+
+        Args:
+            file_path (Union[str, pathlib.Path]): Path to the target Excel
+                .xlsx file.
+            spaces_replacement (str): All the spaces in the rows and columns
+                descriptions (labels) are replaced with this string.
+            label_row_format (dict): Excel styles for the label of rows,
+                documentation: https://xlsxwriter.readthedocs.io/format.html
+            label_column_format (dict): Excel styles for the label of columns,
+                documentation: https://xlsxwriter.readthedocs.io/format.html
+            variables_sheet_name (Optional[str]): If set, creates the new
+                sheet with variables and their description and possibility
+                to set them up (directly from the sheet).
+            variables_sheet_header (Dict[str, str]): Define the labels (header)
+                for the sheet with variables (first row in the sheet).
+            values_only (bool): If true, only values (and not formulas) are
+                exported.
+            skipped_label_replacement (str): Replacement for the SkippedLabel
+                instances.
+            row_height (List[float]): List of row heights, or empty for the
+                default height (or None for default height in the series).
+                If row labels are included, there is a label row height on the
+                first position in array.
+            column_width (List[float]): List of column widths, or empty for the
+                default widths (or None for the default width in the series).
+                If column labels are included, there is a label column width
+                on the first position in array.
+            top_left_corner_text (str): Text in the top left corner. Apply
+                only when the row and column labels are included.
+        """
+        # Quick sanity check
+        if ".xlsx" not in pathlib.Path(file_path).suffix:
+            raise ValueError("Suffix of the file has to be '.xslx'!")
+        if not isinstance(self.name, str) or len(self.name) < 1:
+            raise ValueError("Sheet name has to be non-empty string!")
+
+        workbook = xlsxwriter.Workbook(str(file_path))
+        # Create a sheet inside Excel file:
+        worksheet = workbook.add_worksheet(name=self.name)
+        self._to_excel(
+            spaces_replacement=spaces_replacement,
+            label_row_format=label_row_format,
+            label_column_format=label_column_format,
+            variables_sheet_name=variables_sheet_name,
+            variables_sheet_header=variables_sheet_header,
+            values_only=values_only,
+            skipped_label_replacement=skipped_label_replacement,
+            row_height=row_height,
+            column_width=column_width,
+            top_left_corner_text=top_left_corner_text,
+            workbook=workbook,
+            worksheet=worksheet
+        )
         workbook.close()
 
     def to_dictionary(self,
                       languages: List[str] = None,
                       use_language_for_description: Optional[str] = None,
-                      /, *,  # noqa E999
+                      *,
                       by_row: bool = True,
                       languages_pseudonyms: List[str] = None,
                       spaces_replacement: str = ' ',
                       skip_nan_cell: bool = False,
                       nan_replacement: object = None,
                       error_replacement: object = None,
-                      append_dict: dict = {},
+                      append_dict: dict = MappingProxyType({}),
                       generate_schema: bool = False
                       ) -> T_out_dict:
         """Export this spreadsheet to the dictionary.
@@ -381,7 +590,7 @@ class Serialization(abc.ABC):
                           self.export_offset[1]:self.shape[1]
                           ]
              ]
-        if (x_helptext := self.cell_indices.columns_help_text) is not None:  # noqa E203
+        if (x_helptext := self.cell_indices.columns_help_text) is not None:  # noqa
             # Reflects the column offset for export
             x_helptext = x_helptext[self.export_offset[1]:self.shape[1]]
         x_start_key = 'columns'
@@ -393,7 +602,7 @@ class Serialization(abc.ABC):
                           self.export_offset[0]:self.shape[0]
                           ]
              ]
-        if (y_helptext := self.cell_indices.rows_help_text) is not None:  # noqa E203
+        if (y_helptext := self.cell_indices.rows_help_text) is not None:  # noqa
             # Reflects the row offset for export
             y_helptext = y_helptext[self.export_offset[0]:self.shape[0]]
         y_start_key = 'rows'
@@ -407,7 +616,7 @@ class Serialization(abc.ABC):
                           self.export_offset[0]:self.shape[0]
                           ]
                  ]
-            if (x_helptext := self.cell_indices.rows_help_text) is not None:  # noqa E203
+            if (x_helptext := self.cell_indices.rows_help_text) is not None:  # noqa
                 # Reflects the row offset for export
                 x_helptext = x_helptext[self.export_offset[0]:self.shape[0]]
             x_start_key = 'rows'
@@ -418,7 +627,7 @@ class Serialization(abc.ABC):
                           # Reflects the column offset for export
                           self.export_offset[1]:self.shape[1]
                           ]]
-            if (y_helptext := self.cell_indices.columns_help_text) is not None:  # noqa E203
+            if (y_helptext := self.cell_indices.columns_help_text) is not None:  # noqa
                 # Reflects the column offset for export
                 y_helptext = y_helptext[self.export_offset[1]:self.shape[1]]
             y_start_key = 'columns'
@@ -477,7 +686,7 @@ class Serialization(abc.ABC):
         data = {'data': values}
 
         # Add variables
-        data['variables'] = self._get_variables().variables_dict
+        data['variables'] = self._get_variables().get_variables_dict(False)
         # Add a row and column labels as arrays
         if not by_row:
             x, y = y, x
@@ -487,7 +696,7 @@ class Serialization(abc.ABC):
         # Add row description (and labels)
         data['rows'] = []
         for idx, x_label in enumerate(x):
-            if isinstance(x[idx_x], SkippedLabel):
+            if isinstance(x_label, SkippedLabel):
                 # Skip labels that are intended to be skipped
                 continue
             metadata: dict = {"name": x_label}
@@ -503,7 +712,7 @@ class Serialization(abc.ABC):
         # Add column description (and labels)
         data['columns'] = []
         for idx, y_label in enumerate(y):
-            if isinstance(y[idx_y], SkippedLabel):
+            if isinstance(y_label, SkippedLabel):
                 # Skip labels that are intended to be skipped
                 continue
             metadata = {"name": y_label}
@@ -527,14 +736,14 @@ class Serialization(abc.ABC):
     def to_json(self,
                 languages: List[str] = None,
                 use_language_for_description: Optional[str] = None,
-                /, *,  # noqa E999
+                *,
                 by_row: bool = True,
                 languages_pseudonyms: List[str] = None,
                 spaces_replacement: str = ' ',
                 skip_nan_cell: bool = False,
                 nan_replacement: object = None,
                 error_replacement: object = None,
-                append_dict: dict = {},
+                append_dict: dict = MappingProxyType({}),
                 generate_schema: bool = False) -> str:
         """Dumps the exported dictionary to the JSON object.
 
@@ -564,17 +773,6 @@ class Serialization(abc.ABC):
                 columns/rows/help_text->Column/Row label->
                 cell keys (value, description, language alias)->value
         """
-        class _NumPyEncoder(json.JSONEncoder):
-            """Encodes the NumPy variables to export"""
-            def default(self, obj):
-                if isinstance(obj, numpy.integer):
-                    return int(obj)
-                elif isinstance(obj, numpy.floating):
-                    return float(obj)
-                elif isinstance(obj, numpy.ndarray):
-                    return obj.tolist()
-                else:
-                    return super(_NumPyEncoder, self).default(obj)
         # Return correctly encoded JSON
         return json.dumps(
             self.to_dictionary(languages, use_language_for_description,
@@ -586,7 +784,7 @@ class Serialization(abc.ABC):
                                error_replacement=error_replacement,
                                append_dict=append_dict,
                                generate_schema=generate_schema),
-            cls=_NumPyEncoder
+            cls=NumPyEncoder
         )
 
     @staticmethod
@@ -594,7 +792,7 @@ class Serialization(abc.ABC):
         """Generate JSON schema.
 
         Returns:
-            dict: JSON schema for the Portable Spreadsheet JSON table output.
+            dict: JSON schema for the Portable Spreadsheet JSON sheet output.
         """
         false = False
         schema = {
@@ -795,21 +993,19 @@ class Serialization(abc.ABC):
                 export += ",\n"
         return export + "]"
 
-    def to_2d_list(self, *,
-                   language: Optional[str] = None,
-                   top_right_corner_text: str = "Sheet",
-                   skip_labels: bool = False,
-                   na_rep: Optional[object] = None,
-                   spaces_replacement: str = ' ',
-                   skipped_label_replacement: str = '') -> List[List[object]]:
-        """Export values 2 dimensional Python array.
+    def to_list(self, *,
+                language: Optional[str] = None,
+                skip_labels: bool = False,
+                na_rep: Optional[object] = None,
+                spaces_replacement: str = ' ',
+                skipped_label_replacement: str = '') -> List[List[object]]:
+        """Export values to two dimensional Python array.
 
         Args:
             language (Optional[str]): If set-up, export the word in this
                 language in each cell instead of values.
             spaces_replacement (str): All the spaces in the rows and columns
                 descriptions (labels) are replaced with this string.
-            top_right_corner_text (str): Text in the top right corner.
             na_rep (str): Replacement for the missing data (cells with value
                 equals to None).
             skip_labels (bool): If true, first row and column with labels is
@@ -829,7 +1025,7 @@ class Serialization(abc.ABC):
             if row_idx == -1:
                 if skip_labels:
                     continue
-                row.append(top_right_corner_text)
+                row.append(self.name)
                 # Insert labels of columns:
                 for col_i in range(self.shape[1]):
                     col_lbl = self.cell_indices.columns_labels[
@@ -867,7 +1063,6 @@ class Serialization(abc.ABC):
 
     def to_csv(self, *,
                language: Optional[str] = None,
-               top_right_corner_text: str = "Sheet",
                skip_labels: bool = False,
                na_rep: Optional[object] = '',
                spaces_replacement: str = ' ',
@@ -883,7 +1078,6 @@ class Serialization(abc.ABC):
                 language in each cell instead of values.
             spaces_replacement (str): All the spaces in the rows and columns
                 descriptions (labels) are replaced with this string.
-            top_right_corner_text (str): Text in the top right corner.
             sep (str): Separator of values in a row.
             line_terminator (str): Ending sequence (character) of a row.
             na_rep (str): Replacement for the missing data.
@@ -895,8 +1089,7 @@ class Serialization(abc.ABC):
         Returns:
             str: CSV of the values
         """
-        sheet_as_array = self.to_2d_list(
-            top_right_corner_text=top_right_corner_text,
+        sheet_as_array = self.to_list(
             na_rep=na_rep,
             skip_labels=skip_labels,
             spaces_replacement=spaces_replacement,
@@ -915,7 +1108,6 @@ class Serialization(abc.ABC):
 
     def to_markdown(self, *,
                     language: Optional[str] = None,
-                    top_right_corner_text: str = "Sheet",
                     skip_labels: bool = False,
                     na_rep: Optional[object] = '',
                     spaces_replacement: str = ' ',
@@ -928,7 +1120,6 @@ class Serialization(abc.ABC):
                 language in each cell instead of values.
             spaces_replacement (str): All the spaces in the rows and columns
                 descriptions (labels) are replaced with this string.
-            top_right_corner_text (str): Text in the top right corner.
             na_rep (str): Replacement for the missing data.
             skip_labels (bool): If true, first row and column with labels is
                 skipped
@@ -938,8 +1129,7 @@ class Serialization(abc.ABC):
         Returns:
             str: Markdown (MD) compatible table of the values
         """
-        sheet_as_array = self.to_2d_list(
-            top_right_corner_text=top_right_corner_text,
+        sheet_as_array = self.to_list(
             na_rep=na_rep,
             skip_labels=skip_labels,
             spaces_replacement=spaces_replacement,
@@ -999,7 +1189,9 @@ class Serialization(abc.ABC):
         contains_nonumeric_values = False
         for row_idx in range(self.shape[0]):
             for col_idx in range(self.shape[1]):
-                if (value := self._get_cell_at(row_idx, col_idx).value) is not None:  # noqa E999
+                if (
+                    value := self._get_cell_at(row_idx, col_idx).value  # noqa
+                ) is not None:
                     if isinstance(value, Number):
                         results[row_idx, col_idx] = value
                     else:
@@ -1018,7 +1210,6 @@ class Serialization(abc.ABC):
 
     def to_html_table(self, *,
                       spaces_replacement: str = ' ',
-                      top_right_corner_text: str = "Sheet",
                       na_rep: str = '',
                       language_for_description: str = None,
                       skip_labels: bool = False,
@@ -1028,7 +1219,6 @@ class Serialization(abc.ABC):
         Args:
             spaces_replacement (str): All the spaces in the rows and columns
                 descriptions (labels) are replaced with this string.
-            top_right_corner_text (str): Text in the top right corner.
             na_rep (str): Replacement for the missing data.
             language_for_description (str): If not None, the description
                 of each computational cell is inserted as word of this
@@ -1051,7 +1241,7 @@ class Serialization(abc.ABC):
             export += "<tr>"
             if row_idx == -1:
                 export += "<th>"
-                export += top_right_corner_text
+                export += self.name
                 export += "</th>"
                 # Insert labels of columns:
                 for col_i in range(self.shape[1]):
@@ -1061,7 +1251,7 @@ class Serialization(abc.ABC):
                         ].replace(' ', spaces_replacement)
                     if isinstance(col, SkippedLabel):
                         col = skipped_label_replacement
-                    if (help_text :=  # noqa 203
+                    if (help_text :=  # noqa: 203
                             self.cell_indices.columns_help_text) is not None:
                         title_attr = ' title="{}"'.format(
                             help_text[col_i + self.export_offset[1]]
@@ -1097,7 +1287,7 @@ class Serialization(abc.ABC):
                 for col_idx in range(self.shape[1]):
                     title_attr = ""
                     cell_at_pos = self._get_cell_at(row_idx, col_idx)
-                    if (description := # noqa 203
+                    if (description := # noqa: 203
                             cell_at_pos.description) is not None:
                         title_attr = ' title="{}"'.format(description)
                     elif language_for_description is not None:
